#
# spec file for package xedit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xedit
Version:        1.2.4
Release:        1.3
Summary:        Simple text editor for X
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Source1:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz.sig
Source2:        xedit.keyring
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xt) >= 1.0
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
Xedit is a simple text editor for X.

%prep
%setup -q
# bnc#684116
cp lisp/README README.lisp
cp lisp/re/README README.re

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc AUTHORS ChangeLog README README.lisp README.re
%{_bindir}/xedit
%{_libdir}/X11/xedit/
%dir %{_datadir}/X11/app-defaults
%{_datadir}/X11/app-defaults/Xedit
%{_datadir}/X11/app-defaults/Xedit-color
%{_mandir}/man1/xedit.1%{?ext_man}
%ifnarch %{ix86}
%dir %{_libdir}/X11
%endif

%changelog
* Mon Mar 25 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to versoin 1.2.4
  * This release adds -help and -version options, removes remnants of
    support for OS/2 & Interactive Unix, and fixes a crash if there
    is a call to an undefined function in lisp.lsp.
* Thu Aug 11 2022 Dirk Müller <dmueller@suse.com>
- modernize spec-file, move license to %%%%licensedir
- use gpg validation
* Mon Apr  4 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.3
  * This minor maintenance release adds support for building on the
    ARM platform for MacOS, as well as some more general bug fixes
    and cleanups for all OS'es.
* Sun Mar  8 2015 zaitor@opensuse.org
- Update to version 1.2.2:
  + Include AM_PROG_AR to detect 'ar' instead of hard-coding it.
  + Use automake subdir-objects option.
  + Check for pagesize options via autoconf instead of per-platform
    [#]ifdefs.
  + Copious const cleanup.
  + Require OS to provide rename(2), as all POSIX.1-1990 & later
    OS'es do.
  + autogen.sh: Honor NOCONFIGURE=1.
  + configure: Drop AM_MAINTAINER_MODE.
  + Fix man page tbl markup.
  + Remove obsolete Imake SIGNALRETURNSINT.
  + Drop CRAY support.
* Sat Jan 19 2013 zaitor@opensuse.org
- Update to version 1.2.1:
  + Remove lisp/env.c from EXTRA_DIST to fix make_distcheck
  + Eliminate use of tab stops. Use real TBL markup.
  + Do not unconditionally define DEBUG.
  + Avoid problems with builds with -Werror=format-security.
  + Use proper pointer when computing "realpath" of a new file.
  + Correct 64 bit overflow check and bignum code.
  + Update fallback implementation of missing libc functions.
  + Fix builds of lisp/core.c with Solaris Studio compilers.
  + Require xt >= 1.0 for appdefaultdir (fdo#7237).
  + config:
  - Replace deprecated AM_CONFIG_HEADER with AC_CONFIG_HEADERS.
  - Replace deprecated AC_HELP_STRING with AS_HELP_STRING.
  - Move man pages into their own directory.
  + man:
  - Replace hard coded man page section with substitution strings
  - Remove trailing spaces and tabs.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xedit from xorg-x11. Initial version: 1.2.0.
